@@ -1,8 +1,6 @@
-from subprocess import CalledProcessError
-
 import pytest
 
-from message_ix import Scenario
+from message_ix import ModelError, Scenario
 
 
 def model_setup(scen, var_cost=1):
@@ -25,7 +23,7 @@ def test_commodity_price(test_mp):
     scen = Scenario(test_mp, "test_commodity_price", "standard", version="new")
     model_setup(scen)
     scen.commit("initialize test model")
-    scen.solve(case="price_commodity_standard")
+    scen.solve(case="price_commodity_standard", quiet=True)
 
     assert scen.var("OBJ")["lvl"] == 1
     assert scen.var("PRICE_COMMODITY")["lvl"][0] == 1
@@ -37,13 +35,14 @@ def test_commodity_price_equality(test_mp):
     scen.commit("initialize test model with negative variable costs")
 
     # negative variable costs and supply >= demand causes an unbounded ray
-    pytest.raises(CalledProcessError, scen.solve)
+    with pytest.raises(ModelError, match="GAMS errored with return code 3"):
+        scen.solve(quiet=True)
 
     # use the commodity-balance equality feature
     scen.check_out()
     scen.add_set("balance_equality", ["comm", "level"])
     scen.commit("set commodity-balance for `[comm, level]` as equality")
-    scen.solve(case="price_commodity_equality")
+    scen.solve(case="price_commodity_equality", quiet=True)
 
     assert scen.var("OBJ")["lvl"] == -1
     assert scen.var("PRICE_COMMODITY")["lvl"][0] == -1
