@@ -11,8 +11,8 @@ AT = "Austrian_energy_system"
 
 # Common marks for some test cases
 mark0 = pytest.mark.skipif(
-    condition=sys.version_info.minor <= 6 and sys.platform != "linux",
-    reason="R/reticulate link fails on GitHub Actions runners for Python 3.6",
+    condition="GITHUB_ACTIONS" in os.environ and sys.platform == "linux",
+    reason="IR kernel times out on GitHub Actions Ubuntu runners ",
 )
 
 # This mark does *not* affect macos-latest-py3.9, which must still pass
@@ -34,7 +34,7 @@ tutorials: List[Tuple] = [
     # IPython kernel
     (
         ("westeros", "westeros_baseline"),
-        [("solve-objective-value", 193718.421875)],
+        [("solve-objective-value", 173795.09375)],
         {},
     ),
     # NB could also check objective function values in the following tutorials; however,
@@ -51,7 +51,7 @@ tutorials: List[Tuple] = [
     (("westeros", "westeros_addon_technologies"), [], {}),
     (("westeros", "westeros_historical_new_capacity"), [], {}),
     # NB this is the same value as in test_reporter()
-    (("westeros", "westeros_report"), [("len-rep-graph", 12689)], {}),
+    (("westeros", "westeros_report"), [("len-rep-graph", 12690)], {}),
     ((AT, "austria"), [("solve-objective-value", 206321.90625)], {}),
     (
         (AT, "austria_single_policy"),
